@@ -72,7 +72,11 @@ class WatchdogHandler(FileSystemEventHandler):
     def __init__(self, config_path: Path, reload_event: asyncio.Event):
         self.config_path = config_path
         self.reload_event = reload_event
-        self._loop = asyncio.get_event_loop()
+        try:
+            self._loop = asyncio.get_running_loop()
+        except RuntimeError:
+            # Not in an async context, get the event loop
+            self._loop = asyncio.get_event_loop()
 
     def on_modified(self, event):
         """Handle file modification events."""
@@ -135,15 +139,15 @@ class ConfigReloader:
                     recursive=False
                 )
                 self._observer.start()
-                logger.info("Started config file watcher using file system notifications (watchdog)")
+                logger.debug("Started config file watcher using file system notifications (watchdog)")
             except Exception as e:
                 logger.error("Failed to start watchdog observer: %s", e)
-                logger.info("Falling back to polling mode")
+                logger.debug("Falling back to polling mode")
                 self._use_watchdog = False
                 self._observer = None
 
         if not self._use_watchdog:
-            logger.info("Started config file watcher using polling (interval: %.1fs)", poll_interval)
+            logger.debug("Started config file watcher using polling (interval: %.1fs)", poll_interval)
 
         # Start the main watch loop
         self._watch_task = asyncio.create_task(self._watch_loop(poll_interval))
@@ -170,7 +174,7 @@ class ConfigReloader:
             self._watchdog_handler = None
 
         self._watch_task = None
-        logger.info("Stopped config file watcher")
+        logger.debug("Stopped config file watcher")
 
     def ignore_next_change(self) -> None:
         """Tell the reloader to ignore the next file change.
@@ -187,7 +191,14 @@ class ConfigReloader:
         This keeps our internal state in sync when config is saved programmatically.
         """
         self._last_config = config
-        logger.debug("Updated cached config after programmatic save")
+
+    def get_cached_config(self) -> MaggConfig | None:
+        """Get the cached configuration if available.
+
+        Returns:
+            The cached config or None if no config has been loaded yet.
+        """
+        return self._last_config
 
     async def _watch_loop(self, poll_interval: float) -> None:
         """Main watch loop that handles both watchdog and polling modes."""
@@ -238,7 +249,7 @@ class ConfigReloader:
 
         # First time seeing the file
         if self._last_mtime is None:
-            logger.info("Config file appeared: %s", self.config_path)
+            logger.debug("Config file appeared: %s", self.config_path)
             self._last_mtime = current_mtime
             self._last_config = self._load_config()
             return
@@ -252,7 +263,7 @@ class ConfigReloader:
                 self._last_mtime = current_mtime
                 return
 
-            logger.info("Config file changed, reloading...")
+            logger.debug("Config file changed, reloading...")
             await self.reload_config()
             self._last_mtime = current_mtime
 
@@ -311,7 +322,7 @@ class ConfigReloader:
             for name, server_data in data.get('servers', {}).items():
                 try:
                     server_data['name'] = name
-                    servers[name] = ServerConfig(**server_data)
+                    servers[name] = ServerConfig.model_validate(server_data)
                 except Exception as e:
                     logger.error("Error loading server '%s': %s", name, e)
                     continue
@@ -392,17 +403,6 @@ class ConfigReloader:
     def _validate_config(self, config: MaggConfig) -> bool:
         """Validate that the configuration is valid."""
         try:
-            # Check for duplicate prefixes
-            prefixes = {}
-            for name, server in config.servers.items():
-                if server.prefix in prefixes:
-                    logger.error(
-                        "Duplicate prefix '%s' found in servers '%s' and '%s'",
-                        server.prefix, name, prefixes[server.prefix]
-                    )
-                    return False
-                prefixes[server.prefix] = name
-
             # Validate each server
             for name, server in config.servers.items():
                 if not server.command and not server.uri:
@@ -430,6 +430,13 @@ class ReloadManager:
         self._config_reloader: ConfigReloader | None = None
         self._reload_callback: ReloadCallback | None = None
 
+    @property
+    def cached_config(self) -> MaggConfig | None:
+        """Get the cached configuration if available."""
+        if self._config_reloader:
+            return self._config_reloader._last_config
+        return None
+
     async def setup(self, reload_callback: ReloadCallback) -> None:
         """Setup config file watching with a callback.
 
