@@ -5,6 +5,7 @@ import json
 import logging
 import os
 import re
+import shlex
 from functools import wraps
 from pathlib import Path
 from typing import Any, Annotated, Literal
@@ -20,22 +21,22 @@ from ..discovery.metadata import CatalogManager, SourceMetadataCollector
 from ..settings import ServerConfig, ConfigManager
 from ..util.transport import TRANSPORT_DOCS
 from ..util.uri import validate_working_directory
+from ..util.transform import json_to_dict
 
 logger = logging.getLogger(__name__)
 
 
 class MaggServer(ManagedServer):
-    """Main Magg server with tools for managing other MCP servers."""
+    """Main Magg server with tools for managing other MCP servers.
+    """
 
     def __init__(self, config_path: Path | str | None = None, *, enable_config_reload: bool | None = None):
-        # Keep track of whether config reload should be enabled
         config_manager = ConfigManager(config_path)
-        config = config_manager.load_config()
-        enable_config_reload = enable_config_reload if enable_config_reload is not None else config.auto_reload
         super().__init__(ServerManager(config_manager), enable_config_reload=enable_config_reload)
 
     def _register_tools(self):
-        """Register all Magg management tools programmatically."""
+        """Register all Magg management tools programmatically.
+        """
         self_prefix_ = self.self_prefix_
 
         tools = [
@@ -50,6 +51,10 @@ class MaggServer(ManagedServer):
             (self.status, f"{self_prefix_}status", None),
             (self.check, f"{self_prefix_}check", None),
             (self.reload_config_tool, f"{self_prefix_}reload_config", None),
+            (self.load_kit, f"{self_prefix_}load_kit", None),
+            (self.unload_kit, f"{self_prefix_}unload_kit", None),
+            (self.list_kits, f"{self_prefix_}list_kits", None),
+            (self.kit_info, f"{self_prefix_}kit_info", None),
         ]
 
         def call_tool_wrapper(func):
@@ -75,6 +80,8 @@ class MaggServer(ManagedServer):
         resources = [
             (self.get_server_metadata, f"{self.self_prefix}://server/{{name}}"),
             (self.get_all_servers_metadata, f"{self.self_prefix}://servers/all"),
+            (self.get_kit_metadata, f"{self.self_prefix}://kit/{{name}}"),
+            (self.get_all_kits_metadata, f"{self.self_prefix}://kits/all"),
         ]
 
         for method, uri_pattern in resources:
@@ -245,12 +252,12 @@ Documentation for proxy tool:
             description="Full command to run (e.g., 'python server.py', 'npx @playwright/mcp@latest')"
         )] = None,
         uri: Annotated[AnyUrl | None, Field(description="URI for HTTP servers")] = None,
-        env: Annotated[dict[str, str] | None, Field(description="Environment variables")] = None,
+        env: Annotated[dict[str, str] | str | None, Field(description="Environment variables (dict or JSON string)")] = None,
         cwd: Annotated[str | None, Field(description="Working directory (for commands)")] = None,
         notes: Annotated[str | None, Field(description="Setup notes")] = None,
         enable: Annotated[bool | None, Field(description="Whether to enable the server immediately (default: True)")] = True,
-        transport: Annotated[dict[str, Any] | None, Field(
-            description=f"Transport-specific configuration (optional){TRANSPORT_DOCS}"
+        transport: Annotated[dict[str, Any] | str | None, Field(
+            description=f"Transport-specific configuration (dict or JSON string){TRANSPORT_DOCS}"
         )] = None,
     ) -> MaggResponse:
         """Add a new MCP server."""
@@ -263,7 +270,6 @@ Documentation for proxy tool:
             actual_command = command
             actual_args = None
             if command:
-                import shlex
                 parts = shlex.split(command)
                 if len(parts) > 1:
                     actual_command = parts[0]
@@ -282,15 +288,15 @@ Documentation for proxy tool:
                 server = ServerConfig(
                     name=name,
                     source=source,
-                    prefix=prefix or "",
+                    prefix=prefix,
                     command=actual_command,
                     args=actual_args,
                     uri=uri,
-                    env=env,
+                    env=json_to_dict(env),
                     cwd=cwd,
                     notes=notes,
                     enabled=enable if enable is not None else True,
-                    transport=transport or {},
+                    transport=json_to_dict(transport),
                 )
             except ValueError as e:
                 return MaggResponse.error(str(e))
@@ -442,8 +448,6 @@ Documentation for proxy tool:
             if not self.save_config(config):
                 return MaggResponse.error(f"Failed to save configuration for server '{name}'")
 
-            # TODO: Consider calling unmount regardless of suggested state?
-            #       See about race conditions for any case of actions related to config changes when dynamic.
             await self.server_manager.unmount_server(name)
 
             return MaggResponse.success({
@@ -514,11 +518,9 @@ Documentation for proxy tool:
                         project_type = data["project_type"]
                         if project_type == "nodejs_project":
                             config_suggestion["command"] = "npx"
-                            # noinspection PyTypeChecker
                             config_suggestion["args"] = [server_name or Path(source).stem]
                         elif project_type == "python_project":
                             config_suggestion["command"] = "python"
-                            # noinspection PyTypeChecker
                             config_suggestion["args"] = ["-m", server_name or Path(source).stem]
 
                 return MaggResponse.success({
@@ -625,7 +627,6 @@ Documentation for proxy tool:
         except Exception as e:
             return MaggResponse.error(f"Smart configuration failed: {str(e)}")
 
-    # noinspection PyMethodMayBeStatic
     async def search_servers(
         self,
         query: Annotated[str, Field(description="Search query for MCP servers")],
@@ -708,7 +709,6 @@ Please provide:
                 )
 
                 if result and result.text:
-                    # noinspection PyTypeChecker
                     analysis_data["insights"] = result.text
 
             return MaggResponse.success(analysis_data)
@@ -732,7 +732,7 @@ Please provide:
                 "tools": {
                     "total": total_tools,
                 },
-                "prefixes": {s.name: s.prefix for s in config.servers.values()}
+                "prefixes": {name: config.servers[name].prefix for name in self.server_manager.mounted_servers if name in config.servers and config.servers[name].prefix}
             }
 
             return MaggResponse.success(status_data)
@@ -751,13 +751,11 @@ Please provide:
         Note: This operation may briefly interrupt service for affected servers.
         Config reload can also be triggered via SIGHUP signal on Unix systems.
         """
-        # Check if reload is disabled
         if not self.config.auto_reload:
             return MaggResponse.error(
                 "Configuration reload is disabled. Set MAGG_AUTO_RELOAD=true to enable."
             )
 
-        # Check if in read-only mode
         if self.config.read_only:
             return MaggResponse.error(
                 "Configuration reload is not allowed in read-only mode."
@@ -801,7 +799,6 @@ Please provide:
                     continue
 
                 try:
-                    # Use asyncio timeout to prevent hanging
                     async with asyncio.timeout(timeout):
                         async with client:
                             tools = await client.list_tools()
@@ -816,11 +813,9 @@ Please provide:
                     results[server_name] = {"status": "error", "reason": str(e)}
                     unresponsive_servers.append(server_name)
 
-            # Handle unresponsive servers based on action
             actions_taken = []
             if unresponsive_servers and action != "report":
                 if action == "disable":
-                    # Batch disable to avoid multiple config saves
                     config = self.config
                     any_changes = False
 
@@ -840,16 +835,13 @@ Please provide:
                             actions_taken.append(f"Failed to disable {server_name}")
                             results[server_name]["action"] = "disable_failed"
 
-                    # Save config once for all changes
                     if any_changes:
                         if not self.save_config(config):
                             logger.error("Failed to save config after disabling servers")
 
                 else:
-                    # Handle other actions individually
                     for server_name in unresponsive_servers:
                         if action == "remount":
-                            # Unmount then remount
                             await self.server_manager.unmount_server(server_name)
                             server = self.config.servers.get(server_name)
                             if server and server.enabled:
@@ -879,4 +871,4 @@ Please provide:
 
     # ============================================================================
     # endregion
-    # ============================================================================
\ No newline at end of file
+    # ============================================================================
