@@ -1,5 +1,6 @@
 """Transport utilities for Magg - handles FastMCP transport selection and configuration.
 """
+import shlex
 import sys
 from pathlib import Path
 from typing import Any
@@ -15,7 +16,108 @@ from fastmcp.client.transports import (
 )
 from .transports import NoValidatePythonStdioTransport, NoValidateNodeStdioTransport
 
-__all__ = "get_transport_for_command", "get_transport_for_uri", "TRANSPORT_DOCS"
+__all__ = (
+    "get_transport_for_input",
+    "get_transport_for_command", "get_transport_for_command_string", "get_transport_for_uri",
+    "parse_command_string", "TRANSPORT_DOCS"
+)
+
+
+def get_transport_for_input(connect_string: str) -> ClientTransport:
+    """
+    Get appropriate transport based on input string.
+
+    This function determines the type of transport to use based on the input string.
+    It can handle command strings, URIs, and other formats.
+
+    Args:
+        connect_string: Input string that can be a command, URI, or other format
+
+    Returns:
+        Configured ClientTransport instance
+
+    Examples:
+        >>> transport = get_transport_for_input("python -m magg serve")
+        >>> transport = get_transport_for_input("http://localhost:8000")
+    """
+    connect_string = connect_string.strip()
+
+    if not connect_string:
+        raise ValueError("Input cannot be empty")
+
+    # Check if it's a URI (HTTP/SSE)
+    if connect_string.startswith(("http://", "https://")) or "/sse" in connect_string:
+        return get_transport_for_uri(connect_string)
+
+    # Otherwise, treat it as a command string
+    return get_transport_for_command_string(connect_string)
+
+
+def parse_command_string(command_string: str) -> tuple[str, list[str]]:
+    """
+    Parse a command string into command and arguments.
+
+    Uses shell-like parsing to handle quoted arguments properly.
+
+    Args:
+        command_string: Command string like "python -m magg serve" or "npx @playwright/mcp@latest"
+
+    Returns:
+        Tuple of (command, args) where command is the first word and args is the rest
+
+    Examples:
+        >>> parse_command_string("python -m magg serve")
+        ("python", ["-m", "magg", "serve"])
+        >>> parse_command_string('node "my script.js" --port 8000')
+        ("node", ["my script.js", "--port", "8000"])
+    """
+    if not command_string.strip():
+        raise ValueError("Command string cannot be empty")
+
+    try:
+        parts = shlex.split(command_string)
+    except ValueError as e:
+        raise ValueError(f"Invalid command string: {e}") from e
+
+    if not parts:
+        raise ValueError("Command string must contain at least one part")
+
+    return parts[0], parts[1:]
+
+
+def get_transport_for_command_string(
+    command_string: str,
+    env: dict[str, str] | None = None,
+    cwd: Path | None = None,
+    transport_config: dict[str, Any] | None = None
+) -> ClientTransport:
+    """
+    Create appropriate transport for a command string.
+
+    This is a convenience function that combines command string parsing
+    with transport creation.
+
+    Args:
+        command_string: Full command as string (e.g., "python -m magg serve")
+        env: Environment variables
+        cwd: Working directory
+        transport_config: Transport-specific configuration
+
+    Returns:
+        Configured ClientTransport instance
+
+    Examples:
+        >>> transport = get_transport_for_command_string("python -m magg serve")
+        >>> transport = get_transport_for_command_string("npx @playwright/mcp@latest")
+    """
+    command, args = parse_command_string(command_string)
+    return get_transport_for_command(
+        command=command,
+        args=args,
+        env=env,
+        cwd=cwd,
+        transport_config=transport_config
+    )
 
 
 def get_transport_for_command(
